aboutsummaryrefslogtreecommitdiff
path: root/app/converter/clients/base.py
diff options
context:
space:
mode:
authorhistoria <historiavg@proton.me>2026-08-26 21:22:40 -0400
committerhistoria <historiavg@proton.me>2026-08-26 21:22:40 -0400
commit477ac3e827e3bdc9f14583fc3aa8db1fa2d27c52 (patch)
tree1e21fa5af1d7a95ffc62fb03eed153056c38ae9e /app/converter/clients/base.py
parent65c6f737f1545ef225768af897acd20f163a4fb4 (diff)
downloadtts-audiobook-generator-477ac3e827e3bdc9f14583fc3aa8db1fa2d27c52.tar.gz
feat: design model support for qwen-tts backend. remove unnecessary port split for qwen models
Diffstat (limited to 'app/converter/clients/base.py')
-rw-r--r--app/converter/clients/base.py10
1 files changed, 6 insertions, 4 deletions
diff --git a/app/converter/clients/base.py b/app/converter/clients/base.py
index a0f28cf..d0d57fb 100644
--- a/app/converter/clients/base.py
+++ b/app/converter/clients/base.py
@@ -17,12 +17,14 @@ class ConversionCancelled(Exception):
"""Raised when the run's cancel event is set (between requests)."""
# How a run supplies its voice: a built-in CustomVoice speaker, or by
# cloning a reference audio clip (the faster and audiocpp backends always
# clone server-side; only the Qwen client branches on this at request time).
VOICE_MODE_CUSTOM = "custom_voice"
VOICE_MODE_CLONE = "voice_clone"
-VOICE_MODES = (VOICE_MODE_CUSTOM, VOICE_MODE_CLONE)
+VOICE_MODE_DESIGN = "voice_design"
+VOICE_MODES = (VOICE_MODE_CUSTOM, VOICE_MODE_CLONE, VOICE_MODE_DESIGN)
def resolve_request_seed() -> int:
@@ -17,12 +17,14 @@ class ConversionCancelled(Exception):
"""Raised when the run's cancel event is set (between requests)."""
-# How a run supplies its voice: a built-in CustomVoice speaker, or by
-# cloning a reference audio clip (the faster and audiocpp backends always
-# clone server-side; only the Qwen client branches on this at request time).
+# How a run supplies its voice: a built-in CustomVoice speaker, by cloning
+# a reference audio clip (the faster and audiocpp backends always clone
+# server-side; only the Qwen client branches on this at request time), or
+# designed from an instruction (Qwen's VoiceDesign model).
VOICE_MODE_CUSTOM = "custom_voice"
VOICE_MODE_CLONE = "voice_clone"